﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.IO;
using System.Windows.Forms;

using VidyaVitamin.Plugin;

namespace VidyaVitamin.Plugin.PictureImport
{
	public partial class PctImpForm : Form
	{
		private IFirebirdTable table;

		public PctImpForm(IFirebirdTable table)
		{
			this.table = table;

			InitializeComponent();

			FbFieldData[] fds = table.GetTableFields();
			foreach (FbFieldData fd in fds) {
				// ファイル名を格納するスペースがあれば保存対象先と見なす
				if (fd.type == "VARYING" && fd.length >= 260) {
					cmbParts.Items.Add(fd);
				}
			}
			if (cmbParts.Items.Count > 0) {
				cmbParts.SelectedIndex = 0;
			} else {
				DialogResult = DialogResult.Cancel;
			}
		}

		private void btnFolder_Click(object sender, EventArgs e)
		{
			FolderBrowserDialog dlg = new FolderBrowserDialog();
			if (dlg.ShowDialog() == DialogResult.Cancel) return;

			txtFolder.Text = dlg.SelectedPath;
		}

		private void btnOK_Click(object sender, EventArgs e)
		{
			string[] files = Directory.GetFiles(txtFolder.Text);

			FbFieldData fd = (FbFieldData)cmbParts.SelectedItem;

			IFirebirdTable subtable = null;
			string subtname = string.Format("{0}${1}", table.TableName, fd.fieldname);
			if (table.IFirebird.ExistTable(subtname) == true) {
				subtable = table.IFirebird.CreateIFirebirdTable(subtname);
			}

			int index = table.MaxNumber + 1;

			List<DictionaryEntry> es = new List<DictionaryEntry>();
			pgb.Value = 0;
			pgb.Maximum = files.Length;
			Size tsize = new Size(256, 256);
			foreach (string s in files) {
				es.Clear();
				es.Add(new DictionaryEntry(fd.fieldname, s));
				table.Merge(index, es);
				if (subtable != null) {
					// 埋め込み用の画像とサムネイル
					es.Clear();
					try {
						Image img = PictureImport.u.CreateThumbnail(s, tsize, true);

						MemoryStream msj = new MemoryStream(), msp = new MemoryStream();
						img.Save(msj, System.Drawing.Imaging.ImageFormat.Jpeg);
						img.Save(msp, System.Drawing.Imaging.ImageFormat.Png);
						byte[] buf = (msj.Length < msp.Length) ? msj.ToArray() : msp.ToArray();
						es.Add(new DictionaryEntry("THUMB" ,buf));
						msj.Close(); msp.Close();

						es.Add(new DictionaryEntry("BINARY", File.ReadAllBytes(s)));
						subtable.Merge(index, es);
					} catch (Exception ex) {
						System.Diagnostics.Debug.WriteLine(ex.Message);
					}
				}
				index++;
			}
		}
	}
}
